﻿Ext.require('App.Const.Finances');
Ext.define('App.View.Kivii.Finances.Payment.Accept.List', {
    extend: 'System.Control.EntityList',
    entityType: 'Kivii.Finances.Entities.Payment',
    xtype: 'App.View.Kivii.Finances.Payment.Accept.List',
    dataSource: '/Restful/Kivii.Finances.Entities.Payment/QueryEx.json',
    title: '新增到账',
    iconCls: 'x-fa fa-cny',
    filter: {
        IsPayee: true,
        // IsSplit: false,
        OperateTimeGreaterThanOrEqualTo: new Date(new Date().getFullYear(), new Date().getMonth(), 1),
        OperateTimeLessThan: new Date(new Date().getFullYear(), new Date().getMonth(), new Date().getDate() + 1)
    },
    viewModel: {
        data: {
            _selection: null
        }
    },
    bind: {
        selection: '{_selection}'
    },
    store: {
        autoLoad: true,
        pageSize: 400,
        sorters: [{
            property: 'OperateTime',
            direction: 'DESC'
        }]
    },
    selModel: {
        selType: 'checkboxmodel',
        checkboxSelect: true,
        pruneRemoved: false,
        extensible: 'y'
    },
    features: [{
        ftype: 'summary'
    }],
    dockedItems: [{
        xtype: 'pagingtoolbar',
        dock: 'bottom',
        displayInfo: true,
        items: [{
            xtype: 'button',
            labelWidth: 60,
            iconCls: 'x-fa fa-check-square-o',
            bind: {
                text: '已选择{selectionCount}条记录,点击清除',
                hidden: '{selectionCount==0}'
            },
            handler: '_onClearSelections'
        }]
    }, {
        xtype: 'toolbar',
        dock: 'top',
        overflowHandler: 'scroller',
        items: [{
                xtype: 'combo',
                queryMode: 'local',
                displayField: 'displayInfo',
                valueField: 'isPayee',
                value: true,
                editable: false,
                filterPickList: true,
                reference: 'isPayee',
                store: {
                    fields: ['displayInfo', 'isPayee'],
                    data: [{
                        displayInfo: '收款',
                        isPayee: true
                    }, {
                        displayInfo: '付款',
                        isPayee: false
                    }]
                },
                listeners: {
                    select: '_onSelectIsPayee'
                }
            }, {
                xtype: 'datefield',
                fieldLabel: '时间范围  开始',
                format: 'Y-m-d',
                labelWidth: 90,
                reference: 'startTime',
                editable: false,
                value: new Date(new Date().getFullYear(), new Date().getMonth(), 1),
                listeners: {
                    select: '_onSelectMonth'
                }
            },
            {
                xtype: 'datefield',
                fieldLabel: '结束',
                format: 'Y-m-d',
                labelWidth: 30,
                reference: 'endTime',
                editable: false,
                value: new Date(new Date().getFullYear(), new Date().getMonth(), new Date().getDate() + 1),
                listeners: {
                    select: '_onSelectMonth'
                }
            }, {
                xtype: 'searchField',
                flex: 1,
                minWidth: 250,
                labelWidth: 60,
                queryField: 'SerialNumber,PayerName,PayerAccountName,PayerAccountSerialNumber',
                emptyText: '模糊搜索流水号、付款单位、收付款账号或名称',
            }, {
                text: '新增到账',
                iconCls: 'x-fa fa-plus',
                menu: [{
                    text: '银行到账',
                    iconCls: 'x-fa fa-bank',
                    type: 'Bank',
                    // disabled: true,
                    handler: '_onAccept'
                }, {
                    text: '新增现金',
                    iconCls: 'x-fa fa-cny',
                    type: 'Cash',
                    handler: '_onAccept'
                }, {
                    text: '新增刷卡',
                    iconCls: 'x-fa fa-credit-card',
                    type: 'Pos',
                    handler: '_onAccept'
                }]
            }, {
                xtype: 'splitbutton',
                text: '作废记录',
                iconCls: 'x-fa fa-window-close-o',
                handler: '_onOffsetList',
                menu: [{
                    text: '作废',
                    iconCls: 'x-fa fa-trash',
                    handler: '_onOffsetPayment',
                    bind: {
                        disabled: '{!_selection}'
                    }
                }]
            }
        ]
    }],
    columns: {
        defaults: {
            menuDisabled: true,
            sortable: true
        },
        items: [{
            xtype: 'rownumberer',
            align: 'center',
            resizable: false
        }, {
            text: '流水号',
            dataIndex: 'SerialNumber',
            width: 120
        }, {
            text: '所属范围',
            dataIndex: 'OwnerName',
            width: 120
        }, {
            text: '付款单位',
            dataIndex: 'PayerName',
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return '合计 ￥';
            },
            width: 220
        }, {
            text: '发生金额',
            align: 'right',
            dataIndex: 'Amount',
            renderer: KiviiContext.Const.FinancesFunctionsMoneyToFmoney,
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return Ext.String.format('{0}', value.toFixed(2));
            },
            width: 110
        }, {
            text: '已认领',
            align: 'right',
            dataIndex: 'AmountSplited',
            renderer: '_renderAmount',
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return Ext.String.format('{0}', value.toFixed(2));
            },
            width: 90
        }, {
            text: '开票金额',
            align: 'right',
            dataIndex: 'AmountInvoice',
            renderer: '_renderAmount',
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return Ext.String.format('{0}', value.toFixed(2));
            },
            width: 100
        }, {
            text: '已用金额',
            align: 'right',
            dataIndex: 'AmountUsed',
            renderer: '_renderAmount',
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return Ext.String.format('{0}', value.toFixed(2));
            },
            width: 100
        }, {
            xtype: 'datecolumn',
            text: '发生日期',
            format: 'Y-m-d H:i',
            dataIndex: 'OperateTime',
            width: 150
        }, {
            text: '付款类型',
            dataIndex: 'Type',
            renderer: '_renderType',
            width: 100
        }, {
            text: '操作人',
            dataIndex: 'OperatorName',
            width: 100
        }, {
            text: '摘要',
            dataIndex: 'Summary',
            width: 150
        }, {
            text: '付款银行',
            dataIndex: 'PayerAccountName',
            width: 280
        }, {
            text: '付款账号',
            dataIndex: 'PayerAccountSerialNumber',
            width: 180
        }, {
            text: '备注',
            dataIndex: 'Remark',
            flex: 1
        }]
    },
    listeners: {
        activate: '_onActivate'
    },
    controller: {
        _onClearSelections: function() {
            this.getView().clearSelections();
        },
        _onActivate: function(_ctrl, _eOpts) {
            this.getView().reload();
        },
        _renderAmount: function(_value, _meta, _record, _rowIndex) {
            if (_value === _record.data.Amount) {
                _meta.style = 'background-color:#B4EEB4';
            }
            return KiviiContext.Const.FinancesFunctionsMoneyToFmoney(_value);
        },
        _renderType: function(_value, _meta, _record, _rowIndex) {
            if (_value === 'Cash') {
                return '现金';
            }
            if (_value === 'Pos') {
                return '刷卡';
            }
            if (_value === 'AliPay') {
                return '支付宝';
            }
            if (_value === 'WeChat') {
                return '微信';
            }
            if (_value === 'Bank') {
                return '银行转账';
            }
            return _value;
        },


        _onSelectMonth: function(_ctrl, _time, _eOpts) {
            let _controller = this;
            let _view = _controller.getView();
            let _refs = _controller.getReferences();
            let _startTime = _refs.startTime.value;
            let _endTime = _refs.endTime.value || new Date();
            if (_startTime === null) {
                Ext.toast("请选择开始时间!");
                return;
            }
            if (_startTime > _endTime) {
                Ext.toast("开始日期不能大于结束日期!");
                return;
            }
            delete _view.filter.OperateTimeGreaterThanOrEqualTo;
            delete _view.filter.OperateTimeLessThan;
            _view.filter.OperateTimeGreaterThanOrEqualTo = new Date(_startTime.getFullYear(), _startTime.getMonth(), _startTime.getDate());
            _view.filter.OperateTimeLessThan = new Date(_endTime.getFullYear(), _endTime.getMonth(), _endTime.getDate() + 1);
            _view.reload();
        },
        _onSelectIsPayee: function(_ctrl, _record) {
            let _controller = this;
            let _view = _controller.getView();
            _view.filter.IsPayee = _record.data.isPayee;
            _view.reload();
        },
        _onAccept: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();

            let _item = {};
            _item.Metadata = {};
            _item.Kvid = null;
            _item.Type = _ctrl.type;
            _item.OwnerType = "Organization";
            _item.PayeeName = KiviiContext.CurrentMember.OrganizationName;
            _item.OperateTime = new Date();
            _item.Currency = 'CNY';

            let _form = Ext.create('App.Control.Kivii.Finances.Payment.Accept.Form', {
                header: false
            });
            let _win = Ext.create('Ext.window.Window', {
                layout: 'fit',
                title: _ctrl.text,
                iconCls: _ctrl.iconCls,
                iconAlign: 'left',
                // header:false,
                autoScroll: true,
                width: 850,
                height: 410,
                modal: true,
                resizable: false,
                items: [_form]
            });
            _form.setOwner(_item, _ctrl);
            _win.show();
            _form.on('entityCreated', function(_ctrl, _entity) {
                _win.close();
                _view.reload();
            });
        },
        _onOffsetPayment: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            let _msg = Ext.create('Ext.window.MessageBox', {
                iconCls: _ctrl.iconCls,
                iconAlign: 'left',
                closeAction: 'destroy'
            });
            _msg.show({
                title: _ctrl.text,
                msg: '是否作废选中' + _selecteds.length + '条到账记录?<br />请填写原因:',
                width: 300,
                buttons: Ext.MessageBox.OKCANCEL,
                multiline: true,
                scope: _controller,
                fn: _controller._offsetPayments,
                animateTarget: _ctrl
            });
            return;
        },
        _offsetPayments: function(_btn, _text, _ctrl) {
            if (_btn !== 'ok') return;
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            let _kvids = [];
            for (let _i = 0; _i < _selecteds.length; _i++) {
                _kvids.push(_selecteds[_i].data.Kvid);
            }
            Ext.Ajax.request({
                url: '/Restful/Kivii.Finances.Entities.Payment/Offset.json',
                jsonData: {
                    Kvids: _kvids,
                    Remark: _text
                },
                success: function(_response) {
                    let _rtns = Ext.decode(_response.responseText);
                    Ext.toast('到账作废成功！');
                    _view.reload();
                },
                failure: function(_response) {
                    _me.unmask();
                }
            });
        },
        _onOffsetList: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();
            let _form = Ext.create('App.Control.Kivii.Finances.Payment.Offset.List', {
                header: false
            });
            let _win = Ext.create('Ext.window.Window', {
                layout: 'fit',
                title: _ctrl.text,
                iconCls: _ctrl.iconCls,
                iconAlign: 'left',
                // header:false,
                autoScroll: true,
                width: 1200,
                height: 650,
                modal: true,
                maximizable: true,
                resizable: true,
                items: [_form]
            });
            _win.show();
            _win.on('close', function(_ctrl, _entity) {
                _view.reload();
            });
        }
    }
});